Learn R Programming

bushtucker (version 0.1.0)

trials: IACGMOOH bushtucker trials data

Description

Data on each of the viewer votes in the first 24 seasons of the UK TV show "I'm A Celebrity, Get Me Out Of Here"

Usage

trials

Arguments

Format

trials

A data frame with 506 rows and 8 columns:

season

(numeric) Season of the show

number

(numeric) Number of the trial (i.e. 1 = the first trial of the season, 2 = second trial of the season, etc.)

date

(Date) Date of the trial

name

(character) Name of the trial

live

(logical) TRUE if the trial was broadcast live, FALSE otherwise

chosen_by

(character) Who chose the contestants for the trial? One of: 'public' if it was by public/viewer vote; 'contestants' if the campmates chose amongst themselves; or 'showrunners' if the trial was compulsory for the chosen contestants

contestant

(character) First name(s) of the contestant(s) that took part in the trial. Where there are multiple contestants, they are separated by a semi-colon.

stars_available

(numeric) Maximum number of stars available to win in this trial

stars_won

(numeric) Number of stars that the contestant(s) won in the trial

Examples

Run this code
{
# How many stars won across all episodes?
sum(trials$stars_won)

# How many trials have been live?
sum(trials$live)
}

Run the code above in your browser using DataLab