- season
(numeric) Season of the show
- day
(numeric) Day of the vote (i.e. number of days after the season started)
- vote
(numeric) Number of the vote (i.e. 1 = the first vote of the season,
2 = second vote of the season, etc. - useful for situations like the final where there are
two votes on the same day.)
- contestant
(character) First name of a celebrity contestant competing in the vote
- result
(character) One of: 'safe' if the celebrity was NOT eliminated, 'eliminated' if they WERE
eliminated, or NA if they did not take part (i.e. had been eliminated or withdrew in an earlier vote)
- position
(numeric) Where it is known, their position in this vote (i.e. 1 = received the most
votes, 2 = second-most votes etc.)
- vote_share
(numeric) Where it is known, the proportion of all votes the celebrity received